@@ -16,9 +16,10 @@ from colorama import Fore, Style
 
 from toncli.modules.deploy_contract import ContractDeployer
 from toncli.modules.projects import ProjectBootstrapper
+from toncli.modules.tests.tests import TestsRunner
 from toncli.modules.utils.func.func import Func
 from toncli.modules.utils.system.argparse_fix import argv_fix
-from toncli.modules.utils.system.conf import config_file
+from toncli.modules.utils.system.conf import config_file, getcwd
 from toncli.modules.utils.system.log import logger
 from toncli.modules.utils.fift.cli_lib import process_build_cli_lib_command
 from toncli.modules.utils.fift.fift import Fift
@@ -114,7 +115,7 @@ Credits: {gr}disintar.io{rs} team
 
     # This is concept of nft https://disintar.io
     # Nft information parse will be added in next versions of CLI
-    print("beta.disintar.io NFT owners today say: 🙈 🙉 🙊")
+    # print("disintar.io NFT owners today say: 🙈 🙉 🙊")
 
     # TODO: add logging verbose
     parser = argparse.ArgumentParser(
@@ -300,7 +301,16 @@ You can update them automatically using "toncli update_libs" or disable this war
     #
     #  WALLET
     #
-    parser_wallet = subparser.add_parser('wallet')
+    wallet = subparser.add_parser('wallet')
+
+    #
+    #  TESTS
+    #
+    run_tests = subparser.add_parser('run_tests')
+    run_tests.add_argument("--contracts", "-c", type=str,
+                           help='Set contract name from project.yaml to run tests on')
+    run_tests.add_argument("--verbose", "-v", type=int, default=0,
+                           help='Set contract name from project.yaml to run tests on')
 
     #
     #  UPDATE LIBS
@@ -366,12 +376,15 @@ You can update them automatically using "toncli update_libs" or disable this war
     elif command == 'get':
         _, kwargs = argv_fix(sys.argv, string_kwargs)
         args = parser.parse_args(['get', *kwargs])
+    elif command == 'run_tests':
+        _, kwargs = argv_fix(sys.argv, string_kwargs)
+        args = parser.parse_args(['run_tests', *kwargs])
     elif command == 'addrs':
-        if 'project.yaml' not in os.listdir(os.getcwd()):
-            logger.error(f"🚫 {gr}{os.getcwd()}{rs} is not project root, there is no file {bl}project.yaml{rs} file")
+        if 'project.yaml' not in os.listdir(getcwd()):
+            logger.error(f"🚫 {gr}{getcwd()}{rs} is not project root, there is no file {bl}project.yaml{rs} file")
             sys.exit(0)
 
-        contract = ContractDeployer(network='ownnet')
+        contract = ContractDeployer(network='testnet')
         addrs = contract.get_address()
 
         for name, addr in zip(contract.project_config.contracts, addrs):
@@ -518,14 +531,15 @@ You can update them automatically using "toncli update_libs" or disable this war
         contract_addr_file_name = 'build/contract_address'
         if os.path.isfile(contract_addr_file_name):
             bounceable_addr = ""
-            with open(contract_addr_file_name, 'r') as file:
+            with open(contract_addr_file_name, 'r', encoding='utf-8') as file:
                 addresses = file.read().split()
                 bounceable_addr = addresses[2]
             logger.info(f"Your bounceable address is: {gr}{bounceable_addr}{rs}")
 
             deploy_wallet_addr_dir = user_config_dir('toncli')
             deploy_bouncable = ""
-            with open(f"{deploy_wallet_addr_dir}/wallet/build/contract_address", 'r') as file:
+            with open(os.path.abspath(f"{deploy_wallet_addr_dir}/wallet/build/contract_address"), 'r',
+                      encoding='utf-8') as file:
                 addresses = file.read().split()
                 deploy_bouncable = addresses[2]
             logger.info(f"Your deploy wallet address is: {gr}{deploy_bouncable}{rs}")
@@ -539,10 +553,14 @@ You can update them automatically using "toncli update_libs" or disable this war
     elif command == 'update_libs':
         global_lib_path, local_lib_path = get_libs_paths()
 
-        shutil.copytree(f"{global_lib_path}/fift-libs", f"{local_lib_path}/fift-libs", dirs_exist_ok=True)
-        shutil.copytree(f"{global_lib_path}/func-libs", f"{local_lib_path}/func-libs", dirs_exist_ok=True)
+        shutil.copytree(os.path.abspath(f"{global_lib_path}/fift-libs"), os.path.abspath(f"{local_lib_path}/fift-libs"),
+                        dirs_exist_ok=True)
+        shutil.copytree(os.path.abspath(f"{global_lib_path}/func-libs"), os.path.abspath(f"{local_lib_path}/func-libs"),
+                        dirs_exist_ok=True)
         logger.info(f"Succesfully copied fift and func libs\nfrom {global_lib_path}\nto {local_lib_path}")
-
+    elif command == 'run_tests':
+        test_runner = TestsRunner()
+        test_runner.run(args.contracts, verbose=args.verbose)
     else:
         logger.error("🔎 Can't find such command")
         sys.exit()
